==> luna_cow-0.6.82-py3-none-any.whl: cow/manager/process.py <==
"""Implements process for process manager."""

import multiprocessing as mp
from typing import Callable, Optional

from .reloaders import SanicReloader


class Process:
    """
    Wrapper around multiprocessing.Process that allows to restart wrapped process.

    Attributes:
        target: target for mp.Process
        name: process name
        process: mp.Process
        restarting: A bool, whether process is restarting. Used to distinguish failure from expected exit.
    """

    def __init__(self, name: str, target: Callable):
        """
        Args:
            name: name of the process
            target: target function for mp.Process
        """

        self.name = name
        self.target: Callable = target
        self.process: Optional[mp.Process] = None
        self.restarting = False

    def start(self, restart=False):
        """
        Start or restart the process.

        Sets restarting to True during the restart, so the manager can distinguish between
        failure and restart.

        Args:
            restart: A bool, whether to restart process if its running.
        """
        if self.process is not None and not restart:
            return

        if self.process:
            self.restarting = True
            self.stop()

        process = self.makeProcess()
        process.start()
        self.process = process
        self.restarting = False

    def stop(self):
        """Stop the process."""
        self.process.terminate()
        self.process.join()

    def restart(self):
        """Restart the process."""
        self.start(restart=True)

    def isAlive(self) -> bool:
        """Check whether the process is alive."""
        return self.process.is_alive()

    def makeProcess(self) -> mp.Process:
        """Configure and return Process instance."""
        ctx = mp.get_context("spawn")
        return ctx.Process(target=self.target, name=self.name)


class SanicProcess(Process):
    """Generic class for sanic web application process."""

    sock = None

    def getReloader(self, config) -> SanicReloader:
        """Fabric for reloader instance for sanic application process."""
        return SanicReloader(self, config)

    def makeProcess(self) -> mp.Process:
        """Configure and return Process instance."""
        ctx = mp.get_context("spawn")

        if self.sock:
            return ctx.Process(target=self.target, name=self.name, args=(self.sock,))

        return ctx.Process(target=self.target, name=self.name)

==> luna_cow-0.8.23-py3-none-any.whl: cow/manager/process.py <==
"""Implements process for process manager."""

import multiprocessing as mp
from typing import Callable, Optional

from .reloaders import SanicReloader


class Process:
    """
    Wrapper around multiprocessing.Process that allows to restart wrapped process.

    Attributes:
        target: target for mp.Process
        name: process name
        process: mp.Process
        restarting: A bool, whether process is restarting. Used to distinguish failed from expected exit.
    """

    def __init__(self, name: str, target: Callable):
        """
        Args:
            name: name of the process
            target: target function for mp.Process
        """

        self.name = name
        self.target: Callable = target
        self.process: Optional[mp.Process] = None
        self.restarting = False

    def start(self, restart=False):
        """
        Start or restart the process.

        Sets restarting to True during the restart, so the manager can distinguish between
        failed and restart.

        Args:
            restart: A bool, whether to restart process if its running.
        """
        if self.process is not None and not restart:
            return

        if self.process:
            self.restarting = True
            self.stop()

        process = self.makeProcess()
        process.start()
        self.process = process
        self.restarting = False

    def stop(self):
        """Stop the process."""
        self.process.terminate()
        self.process.join()

    def restart(self):
        """Restart the process."""
        self.start(restart=True)

    def isAlive(self) -> bool:
        """Check whether the process is alive."""
        return self.process.is_alive()

    def makeProcess(self) -> mp.Process:
        """Configure and return Process instance."""
        ctx = mp.get_context("spawn")
        return ctx.Process(target=self.target, name=self.name)


class SanicProcess(Process):
    """Generic class for sanic web application process."""

    sock = None

    def getReloader(self, config) -> SanicReloader:
        """Fabric for reloader instance for sanic application process."""
        return SanicReloader(self, config)

    def makeProcess(self) -> mp.Process:
        """Configure and return Process instance."""
        ctx = mp.get_context("spawn")

        if self.sock:
            return ctx.Process(target=self.target, name=self.name, args=(self.sock,))

        return ctx.Process(target=self.target, name=self.name)
